==> cli-latextable-0.112.tar.gz: cli-latextable-0.112/lib/cli/latextable.pm <==
package cli::latextable;

use 5.014;
use strict;
use warnings;

=head1 NAME

cli::latextable 
  Command to produce LaTeX table 
  from TSV format data and also
  from EXCEL tables by copy-paste.


=head1 VERSION

Version 0.112

=cut

our $VERSION = '0.112';


=head1 SYNOPSIS

  You can easily produce LaTeX table from "\begin{table}.."
  from tab-character separated variable (TSV) format, so
  it is easy even from Excel or SQL output by "copy-paste".

  Just type on your terminal as :

     latextable  

  and it accepts the input, for example, your pasting of 
  the copying from Excel or other SQL table. First trial
  would be your typing "Hello\tWorld!" ("\t" means Tab) 
  into the input of this command.

  Online manual is available by : 

    latextable --help [en/ja/opt] # Both English and Japanese.
   

=head1 AUTHOR

"Toshiyuki Shimono", C<< <bin4tsv at gmail.com> >>

=head1 BUGS

Please report any bugs or feature requests to bin4tsv at gmail period/dot com.


=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc cli::latextable



=head1 LICENSE AND COPYRIGHT

Copyright 2018 "Toshiyuki Shimono".

This program is free software; you can redistribute it and/or modify it
under the terms of the the Artistic License (2.0). You may obtain a
copy of the full license at:

L<http://www.perlfoundation.org/artistic_license_2_0>

Any use, modification, and distribution of the Standard or Modified
Versions is governed by this Artistic License. By using, modifying or
distributing the Package, you accept this license. Do not use, modify,
or distribute the Package, if you do not accept this license.

If your Modified Version has been derived from a Modified Version made
by someone other than you, you are nevertheless required to ensure that
your Modified Version complies with the requirements of this license.

This license does not grant you the right to use any trademark, service
mark, tradename, or logo of the Copyright Holder.

This license includes the non-exclusive, worldwide, free-of-charge
patent license to make, have made, use, offer to sell, sell, import and
otherwise transfer the Package with respect to any patent claims
licensable by the Copyright Holder that are necessarily infringed by the
Package. If you institute patent litigation (including a cross-claim or
counterclaim) against any party alleging that the Package constitutes
direct or contributory patent infringement, then this Artistic License
to you shall terminate on the date that such litigation is filed.

Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY
YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


=cut

1; # End of cli::latextable

==> cli-latextable-0.113.tar.gz: cli-latextable-0.113/lib/cli/latextable.pm <==
package cli::latextable;

use 5.014;
use strict;
use warnings;

=head1 NAME

cli::latextable 
  Command to produce LaTeX table 
  from TSV format data and also
  from EXCEL tables or SQL outputs easily by copy-paste.


=head1 VERSION

Version 0.113

=cut

our $VERSION = '0.113';


=head1 SYNOPSIS

  You can easily produce LaTeX table from "\begin{table}.."
  from tab-character separated variable (TSV) format, so
  it is easy even from Excel or SQL output by "copy-paste".

  Just type on your terminal as :

     latextable  

  and it accepts the input, for example, your pasting of 
  the copying from Excel or other SQL table. First trial
  would be your typing "Hello\tWorld!" ("\t" means Tab) 
  into the input of this command.

  Online manual is available by : 

    latextable --help [en/ja/opt] # Both English and Japanese.
   

=head1 AUTHOR

"Toshiyuki Shimono", C<< <bin4tsv at gmail.com> >>

=head1 BUGS

Please report any bugs or feature requests to bin4tsv at gmail period/dot com.


=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc cli::latextable



=head1 LICENSE AND COPYRIGHT

Copyright 2018 "Toshiyuki Shimono".

This program is free software; you can redistribute it and/or modify it
under the terms of the the Artistic License (2.0). You may obtain a
copy of the full license at:

L<http://www.perlfoundation.org/artistic_license_2_0>

Any use, modification, and distribution of the Standard or Modified
Versions is governed by this Artistic License. By using, modifying or
distributing the Package, you accept this license. Do not use, modify,
or distribute the Package, if you do not accept this license.

If your Modified Version has been derived from a Modified Version made
by someone other than you, you are nevertheless required to ensure that
your Modified Version complies with the requirements of this license.

This license does not grant you the right to use any trademark, service
mark, tradename, or logo of the Copyright Holder.

This license includes the non-exclusive, worldwide, free-of-charge
patent license to make, have made, use, offer to sell, sell, import and
otherwise transfer the Package with respect to any patent claims
licensable by the Copyright Holder that are necessarily infringed by the
Package. If you institute patent litigation (including a cross-claim or
counterclaim) against any party alleging that the Package constitutes
direct or contributory patent infringement, then this Artistic License
to you shall terminate on the date that such litigation is filed.

Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY
YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


=cut

1; # End of cli::latextable
